@@ -20,6 +20,8 @@
 #ifndef ABSTRACTFILELISTING_H
 #define ABSTRACTFILELISTING_H
 
+#include "elisaLib_export.h"
+
 #include "notificationitem.h"
 
 #include <QObject>
@@ -27,6 +29,7 @@
 #include <QUrl>
 #include <QHash>
 #include <QVector>
+#include <QDateTime>
 
 #include <memory>
 
@@ -34,15 +37,11 @@ class AbstractFileListingPrivate;
 class MusicAudioTrack;
 class NotificationItem;
 
-class AbstractFileListing : public QObject
+class ELISALIB_EXPORT AbstractFileListing : public QObject
 {
 
     Q_OBJECT
 
-    Q_PROPERTY(int importedTracksCount
-               READ importedTracksCount
-               NOTIFY importedTracksCountChanged)
-
 public:
 
     explicit AbstractFileListing(const QString &sourceName, QObject *parent = nullptr);
@@ -53,8 +52,6 @@ public:
 
     const QString &sourceName() const;
 
-    int importedTracksCount() const;
-
 Q_SIGNALS:
 
     void tracksList(const QList<MusicAudioTrack> &tracks, const QHash<QString, QUrl> &covers, const QString &musicSource);
@@ -65,14 +62,16 @@ Q_SIGNALS:
 
     void indexingStarted();
 
-    void indexingFinished(int tracksCount);
-
-    void importedTracksCountChanged();
+    void indexingFinished();
 
     void newNotification(NotificationItem notification);
 
     void closeNotification(QString notificationId);
 
+    void askRestoredTracks(const QString &musicSource);
+
+    void errorWatchingFiles();
+
 public Q_SLOTS:
 
     void refreshContent();
@@ -81,7 +80,7 @@ public Q_SLOTS:
 
     void newTrackFile(const MusicAudioTrack &partialTrack);
 
-    void resetImportedTracksCounter();
+    void restoredTracks(const QString &musicSource, QHash<QUrl, QDateTime> allFiles);
 
 protected Q_SLOTS:
 
@@ -91,7 +90,7 @@ protected Q_SLOTS:
 
 protected:
 
-    virtual void executeInit();
+    virtual void executeInit(QHash<QUrl, QDateTime> allFiles);
 
     virtual void triggerRefreshOfContent();
 
@@ -117,7 +116,9 @@ protected:
 
     void setSourceName(const QString &name);
 
-    void increaseImportedTracksCount();
+    QHash<QUrl, QDateTime>& allFiles();
+
+    void checkFilesToRemove();
 
 private:
 
