@@ -22,6 +22,7 @@
 #include "musicaudiotrack.h"
 #include "notificationitem.h"
 #include "elisa_settings.h"
+#include "elisautils.h"
 
 #include "baloo/scheduler.h"
 #include "baloo/fileindexer.h"
@@ -60,24 +61,18 @@ public:
 
     QHash<QString, QVector<MusicAudioTrack>> mAllAlbums;
 
-    QHash<QString, QVector<MusicAudioTrack>> mNewAlbums;
-
-    QList<MusicAudioTrack> mNewTracks;
-
-    QHash<QString, QUrl> mAllAlbumCover;
-
-    QAtomicInt mStopRequest = 0;
-
     QDBusServiceWatcher mServiceWatcher;
 
-    bool mIsRegistered = false;
-
-    bool mIsRegistering = false;
-
     QScopedPointer<org::kde::baloo::fileindexer> mBalooIndexer;
 
     QScopedPointer<org::kde::baloo::scheduler> mBalooScheduler;
 
+    QAtomicInt mStopRequest = 0;
+
+    bool mIsRegistered = false;
+
+    bool mIsRegistering = false;
+
 };
 
 LocalBalooFileListing::LocalBalooFileListing(QObject *parent)
@@ -233,8 +228,9 @@ void LocalBalooFileListing::serviceUnregistered(const QString &serviceName)
     }
 }
 
-void LocalBalooFileListing::executeInit()
+void LocalBalooFileListing::executeInit(QHash<QUrl, QDateTime> allFiles)
 {
+    AbstractFileListing::executeInit(std::move(allFiles));
 }
 
 void LocalBalooFileListing::triggerRefreshOfContent()
@@ -261,12 +257,7 @@ void LocalBalooFileListing::triggerRefreshOfContent()
 
         if (newTrack.isValid()) {
             newFiles.push_back(newTrack);
-            increaseImportedTracksCount();
-            if (newFiles.size() % 50 == 0) {
-                Q_EMIT importedTracksCountChanged();
-            }
             if (newFiles.size() > 500 && d->mStopRequest == 0) {
-                Q_EMIT importedTracksCountChanged();
                 emitNewFiles(newFiles);
                 newFiles.clear();
             }
@@ -274,165 +265,52 @@ void LocalBalooFileListing::triggerRefreshOfContent()
     }
 
     if (!newFiles.isEmpty() && d->mStopRequest == 0) {
-        Q_EMIT importedTracksCountChanged();
         emitNewFiles(newFiles);
     }
 
-    Q_EMIT indexingFinished(importedTracksCount());
+    checkFilesToRemove();
+
+    Q_EMIT indexingFinished();
 }
 
 MusicAudioTrack LocalBalooFileListing::scanOneFile(const QUrl &scanFile)
 {
     auto newTrack = MusicAudioTrack();
 
-    auto fileName = scanFile.toLocalFile();
-    auto scanFileInfo = QFileInfo(fileName);
+    auto localFileName = scanFile.toLocalFile();
+    auto scanFileInfo = QFileInfo(localFileName);
 
     if (scanFileInfo.exists()) {
-        watchPath(fileName);
+        watchPath(localFileName);
+    } else {
+        return newTrack;
     }
 
-    Baloo::File match(fileName);
+    auto itExistingFile = allFiles().find(scanFile);
+    if (itExistingFile != allFiles().end()) {
+        if (*itExistingFile >= scanFileInfo.fileTime(QFile::FileModificationTime)) {
+            allFiles().erase(itExistingFile);
+            return newTrack;
+        }
+    }
+
+    Baloo::File match(localFileName);
+
     match.load();
 
+    newTrack.setFileModificationTime(scanFileInfo.fileTime(QFile::FileModificationTime));
+    newTrack.setResourceURI(scanFile);
+
     const auto &allProperties = match.properties();
 
-    auto titleProperty = allProperties.find(KFileMetaData::Property::Title);
-    auto durationProperty = allProperties.find(KFileMetaData::Property::Duration);
-    auto artistProperty = allProperties.find(KFileMetaData::Property::Artist);
-    auto albumProperty = allProperties.find(KFileMetaData::Property::Album);
-    auto albumArtistProperty = allProperties.find(KFileMetaData::Property::AlbumArtist);
-    auto trackNumberProperty = allProperties.find(KFileMetaData::Property::TrackNumber);
-    auto discNumberProperty = allProperties.find(KFileMetaData::Property::DiscNumber);
-    auto genreProperty = allProperties.find(KFileMetaData::Property::Genre);
-    auto yearProperty = allProperties.find(KFileMetaData::Property::ReleaseYear);
-    auto composerProperty = allProperties.find(KFileMetaData::Property::Composer);
-    auto lyricistProperty = allProperties.find(KFileMetaData::Property::Lyricist);
-    auto channelsProperty = allProperties.find(KFileMetaData::Property::Channels);
-    auto bitRateProperty = allProperties.find(KFileMetaData::Property::BitRate);
-    auto sampleRateProperty = allProperties.find(KFileMetaData::Property::SampleRate);
-    auto commentProperty = allProperties.find(KFileMetaData::Property::Comment);
-    auto fileData = KFileMetaData::UserMetaData(fileName);
-
-    if (albumProperty != allProperties.end()) {
-        auto albumValue = albumProperty->toString();
-        auto &allTracks = d->mAllAlbums[albumValue];
-
-        newTrack.setAlbumName(albumValue);
-
-        if (artistProperty != allProperties.end()) {
-            newTrack.setArtist(artistProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (durationProperty != allProperties.end()) {
-            newTrack.setDuration(QTime::fromMSecsSinceStartOfDay(1000 * durationProperty->toDouble()));
-        }
-
-        if (titleProperty != allProperties.end()) {
-            newTrack.setTitle(titleProperty->toString());
-        }
-
-        if (trackNumberProperty != allProperties.end()) {
-            newTrack.setTrackNumber(trackNumberProperty->toInt());
-        }
-
-        if (discNumberProperty != allProperties.end()) {
-            newTrack.setDiscNumber(discNumberProperty->toInt());
-        } else {
-            newTrack.setDiscNumber(1);
-        }
-
-        if (albumArtistProperty != allProperties.end()) {
-            newTrack.setAlbumArtist(albumArtistProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (newTrack.artist().isEmpty()) {
-            newTrack.setArtist(newTrack.albumArtist());
-        }
-
-        if (yearProperty != allProperties.end()) {
-            newTrack.setYear(yearProperty->toInt());
-        }
-
-        if (channelsProperty != allProperties.end()) {
-            newTrack.setChannels(channelsProperty->toInt());
-        }
-
-        if (bitRateProperty != allProperties.end()) {
-            newTrack.setBitRate(bitRateProperty->toInt());
-        }
-
-        if (sampleRateProperty != allProperties.end()) {
-            newTrack.setSampleRate(sampleRateProperty->toInt());
-        }
-
-        if (genreProperty != allProperties.end()) {
-            newTrack.setGenre(genreProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (composerProperty != allProperties.end()) {
-            newTrack.setComposer(composerProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (lyricistProperty != allProperties.end()) {
-            newTrack.setLyricist(lyricistProperty->toStringList().join(QStringLiteral(", ")));
-        }
-
-        if (commentProperty != allProperties.end()) {
-            newTrack.setComment(commentProperty->toString());
-        }
-
-        newTrack.setRating(fileData.rating());
-
-        newTrack.setResourceURI(scanFile);
-
-        QFileInfo coverFilePath(scanFileInfo.dir().filePath(QStringLiteral("cover.jpg")));
-        if (coverFilePath.exists()) {
-            d->mAllAlbumCover[albumValue] = QUrl::fromLocalFile(coverFilePath.absoluteFilePath());
-        } else {
-            coverFilePath.setFile(scanFileInfo.dir().filePath(QStringLiteral("cover.png")));
-            if (coverFilePath.exists()) {
-                d->mAllAlbumCover[albumValue] = QUrl::fromLocalFile(coverFilePath.absoluteFilePath());
-            }
-        }
-
-        auto itTrack = std::find(allTracks.begin(), allTracks.end(), newTrack);
-        if (itTrack == allTracks.end()) {
-            allTracks.push_back(newTrack);
-            d->mNewTracks.push_back(newTrack);
-            d->mNewAlbums[newTrack.albumName()].push_back(newTrack);
-
-            auto &newTracks = d->mAllAlbums[newTrack.albumName()];
-
-            std::sort(allTracks.begin(), allTracks.end());
-            std::sort(newTracks.begin(), newTracks.end());
-        }
-
-        if (newTrack.title().isEmpty()) {
-            return newTrack;
-        }
-
-        if (newTrack.artist().isEmpty()) {
-            return newTrack;
-        }
-
-        if (newTrack.albumName().isEmpty()) {
-            return newTrack;
-        }
-
-        if (!newTrack.duration().isValid()) {
-            return newTrack;
-        }
-
-        newTrack.setValid(true);
-    }
+    ElisaUtils::scanProperties(localFileName, allProperties, newTrack);
 
     if (!newTrack.isValid()) {
         newTrack = AbstractFileListing::scanOneFile(scanFile);
     }
 
     if (newTrack.isValid()) {
-        addCover(newTrack);
+        AbstractFileListing::addCover(newTrack);
     }
 
     return newTrack;
