@@ -26,7 +26,12 @@
 #include "models/allartistsproxymodel.h"
 #include "models/singleartistproxymodel.h"
 #include "models/singlealbumproxymodel.h"
+#include "models/filebrowserproxymodel.h"
 #include "mediaplaylist.h"
+#include "audiowrapper.h"
+#include "manageaudioplayer.h"
+#include "managemediaplayercontrol.h"
+#include "manageheaderbar.h"
 
 #include "elisa_settings.h"
 #include <KConfigCore/KAuthorized>
@@ -72,6 +77,12 @@ public:
 #endif
     {
         Q_UNUSED(parent)
+
+        auto configurationFileName = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
+        configurationFileName += QStringLiteral("/elisarc");
+        Elisa::ElisaConfiguration::instance(configurationFileName);
+        Elisa::ElisaConfiguration::self()->load();
+        Elisa::ElisaConfiguration::self()->save();
     }
 
 #if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
@@ -88,12 +99,28 @@ public:
 
     std::unique_ptr<AllTracksProxyModel> mAllTracksProxyModel;
 
+    std::unique_ptr<AllArtistsProxyModel> mAllGenresProxyModel;
+
+    std::unique_ptr<AllArtistsProxyModel> mAllComposersProxyModel;
+
+    std::unique_ptr<AllArtistsProxyModel> mAllLyricistsProxyModel;
+
     std::unique_ptr<SingleArtistProxyModel> mSingleArtistProxyModel;
 
     std::unique_ptr<SingleAlbumProxyModel> mSingleAlbumProxyModel;
 
+    std::unique_ptr<FileBrowserProxyModel> mFileBrowserProxyModel;
+
     std::unique_ptr<MediaPlayList> mMediaPlayList;
 
+    std::unique_ptr<AudioWrapper> mAudioWrapper;
+
+    std::unique_ptr<ManageAudioPlayer> mAudioControl;
+
+    std::unique_ptr<ManageMediaPlayerControl> mPlayerControl;
+
+    std::unique_ptr<ManageHeaderBar> mManageHeaderBar;
+
 };
 
 ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::make_unique<ElisaApplicationPrivate>(this))
@@ -141,6 +168,11 @@ void ElisaApplication::setupActions(const QString &actionName)
         d->mCollection.addAction(goBackAction->objectName(), goBackAction);
     }
 
+    if (actionName == QStringLiteral("edit_find") && KAuthorized::authorizeAction(actionName)) {
+        auto findAction = KStandardAction::find(this, &ElisaApplication::find, this);
+        d->mCollection.addAction(findAction->objectName(), findAction);
+    }
+
     d->mCollection.readSettings();
 #endif
 }
@@ -153,6 +185,10 @@ void ElisaApplication::setArguments(const QStringList &newArguments)
 
     d->mArguments = checkFileListAndMakeAbsolute(newArguments, QDir::currentPath());
     Q_EMIT argumentsChanged();
+
+    if (!d->mArguments.isEmpty()) {
+        Q_EMIT enqueue(d->mArguments);
+    }
 }
 
 void ElisaApplication::activateActionRequested(const QString &actionName, const QVariant &parameter)
@@ -227,6 +263,8 @@ void ElisaApplication::configureElisa()
 
 void ElisaApplication::goBack() {}
 
+void ElisaApplication::find() {}
+
 QStringList ElisaApplication::checkFileListAndMakeAbsolute(const QStringList &filesList, const QString &workingDirectory) const
 {
     QStringList filesToOpen;
@@ -247,6 +285,12 @@ QStringList ElisaApplication::checkFileListAndMakeAbsolute(const QStringList &fi
 }
 
 void ElisaApplication::initialize()
+{
+    initializeModels();
+    initializePlayer();
+}
+
+void ElisaApplication::initializeModels()
 {
     d->mMusicManager = std::make_unique<MusicListenersManager>();
     Q_EMIT musicManagerChanged();
@@ -254,12 +298,20 @@ void ElisaApplication::initialize()
     Q_EMIT allAlbumsProxyModelChanged();
     d->mAllArtistsProxyModel = std::make_unique<AllArtistsProxyModel>();
     Q_EMIT allArtistsProxyModelChanged();
+    d->mAllGenresProxyModel = std::make_unique<AllArtistsProxyModel>();
+    Q_EMIT allGenresProxyModelChanged();
+    d->mAllComposersProxyModel = std::make_unique<AllArtistsProxyModel>();
+    Q_EMIT allComposersProxyModelChanged();
+    d->mAllLyricistsProxyModel = std::make_unique<AllArtistsProxyModel>();
+    Q_EMIT allLyricistsProxyModelChanged();
     d->mAllTracksProxyModel = std::make_unique<AllTracksProxyModel>();
     Q_EMIT allTracksProxyModelChanged();
     d->mSingleArtistProxyModel = std::make_unique<SingleArtistProxyModel>();
     Q_EMIT singleArtistProxyModelChanged();
     d->mSingleAlbumProxyModel = std::make_unique<SingleAlbumProxyModel>();
     Q_EMIT singleAlbumProxyModelChanged();
+    d->mFileBrowserProxyModel = std::make_unique<FileBrowserProxyModel>();
+    Q_EMIT fileBrowserProxyModelChanged();
     d->mMediaPlayList = std::make_unique<MediaPlayList>();
     Q_EMIT mediaPlayListChanged();
 
@@ -270,6 +322,9 @@ void ElisaApplication::initialize()
 
     d->mAllAlbumsProxyModel->setSourceModel(d->mMusicManager->allAlbumsModel());
     d->mAllArtistsProxyModel->setSourceModel(d->mMusicManager->allArtistsModel());
+    d->mAllGenresProxyModel->setSourceModel(d->mMusicManager->allGenresModel());
+    d->mAllComposersProxyModel->setSourceModel(d->mMusicManager->allComposersModel());
+    d->mAllLyricistsProxyModel->setSourceModel(d->mMusicManager->allLyricistsModel());
     d->mAllTracksProxyModel->setSourceModel(d->mMusicManager->allTracksModel());
     d->mSingleArtistProxyModel->setSourceModel(d->mMusicManager->allAlbumsModel());
     d->mSingleAlbumProxyModel->setSourceModel(d->mMusicManager->albumModel());
@@ -296,6 +351,69 @@ void ElisaApplication::initialize()
                      d->mMediaPlayList.get(), static_cast<void (MediaPlayList::*)(const QList<MusicAudioTrack> &,
                                                                          ElisaUtils::PlayListEnqueueMode,
                                                                          ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayList::enqueue));
+
+    QObject::connect(d->mFileBrowserProxyModel.get(), &FileBrowserProxyModel::filesToEnqueue,
+                     d->mMediaPlayList.get(), static_cast<void (MediaPlayList::*)(const QList<QUrl> &,
+                                                                         ElisaUtils::PlayListEnqueueMode,
+                                                                         ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayList::enqueue));
+
+}
+
+void ElisaApplication::initializePlayer()
+{
+    d->mAudioWrapper = std::make_unique<AudioWrapper>();
+    Q_EMIT audioPlayerChanged();
+    d->mAudioControl = std::make_unique<ManageAudioPlayer>();
+    Q_EMIT audioControlChanged();
+    d->mPlayerControl = std::make_unique<ManageMediaPlayerControl>();
+    Q_EMIT playerControlChanged();
+    d->mManageHeaderBar = std::make_unique<ManageHeaderBar>();
+    Q_EMIT manageHeaderBarChanged();
+
+    d->mAudioControl->setAlbumNameRole(MediaPlayList::AlbumRole);
+    d->mAudioControl->setArtistNameRole(MediaPlayList::ArtistRole);
+    d->mAudioControl->setTitleRole(MediaPlayList::TitleRole);
+    d->mAudioControl->setUrlRole(MediaPlayList::ResourceRole);
+    d->mAudioControl->setIsPlayingRole(MediaPlayList::IsPlayingRole);
+    d->mAudioControl->setPlayListModel(d->mMediaPlayList.get());
+
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::playerPlay, d->mAudioWrapper.get(), &AudioWrapper::play);
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::playerPause, d->mAudioWrapper.get(), &AudioWrapper::pause);
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::playerStop, d->mAudioWrapper.get(), &AudioWrapper::stop);
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::seek, d->mAudioWrapper.get(), &AudioWrapper::seek);
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::skipNextTrack, d->mMediaPlayList.get(), &MediaPlayList::skipNextTrack);
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::sourceInError, d->mMediaPlayList.get(), &MediaPlayList::trackInError);
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::sourceInError, d->mMusicManager.get(), &MusicListenersManager::playBackError);
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::playerSourceChanged, d->mAudioWrapper.get(), &AudioWrapper::setSource);
+
+    QObject::connect(d->mMediaPlayList.get(), &MediaPlayList::ensurePlay, d->mAudioControl.get(), &ManageAudioPlayer::ensurePlay);
+    QObject::connect(d->mMediaPlayList.get(), &MediaPlayList::playListFinished, d->mAudioControl.get(), &ManageAudioPlayer::playListFinished);
+    QObject::connect(d->mMediaPlayList.get(), &MediaPlayList::currentTrackChanged, d->mAudioControl.get(), &ManageAudioPlayer::setCurrentTrack);
+
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::playbackStateChanged, d->mAudioControl.get(), &ManageAudioPlayer::setPlayerPlaybackState);
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::statusChanged, d->mAudioControl.get(), &ManageAudioPlayer::setPlayerStatus);
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::errorChanged, d->mAudioControl.get(), &ManageAudioPlayer::setPlayerError);
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::durationChanged, d->mAudioControl.get(), &ManageAudioPlayer::setAudioDuration);
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::seekableChanged, d->mAudioControl.get(), &ManageAudioPlayer::setPlayerIsSeekable);
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::positionChanged, d->mAudioControl.get(), &ManageAudioPlayer::setPlayerPosition);
+
+    d->mPlayerControl->setPlayListModel(d->mMediaPlayList.get());
+    QObject::connect(d->mMediaPlayList.get(), &MediaPlayList::currentTrackChanged, d->mPlayerControl.get(), &ManageMediaPlayerControl::setCurrentTrack);
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::playing, d->mPlayerControl.get(), &ManageMediaPlayerControl::playerPlaying);
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::paused, d->mPlayerControl.get(), &ManageMediaPlayerControl::playerPaused);
+    QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::stopped, d->mPlayerControl.get(), &ManageMediaPlayerControl::playerStopped);
+
+    d->mManageHeaderBar->setTitleRole(MediaPlayList::TitleRole);
+    d->mManageHeaderBar->setAlbumRole(MediaPlayList::AlbumRole);
+    d->mManageHeaderBar->setArtistRole(MediaPlayList::ArtistRole);
+    d->mManageHeaderBar->setImageRole(MediaPlayList::ImageRole);
+    d->mManageHeaderBar->setIsValidRole(MediaPlayList::IsValidRole);
+    d->mManageHeaderBar->setPlayListModel(d->mMediaPlayList.get());
+    QObject::connect(d->mMediaPlayList.get(), &MediaPlayList::currentTrackChanged, d->mManageHeaderBar.get(), &ManageHeaderBar::setCurrentTrack);
+
+    if (!d->mArguments.isEmpty()) {
+        Q_EMIT enqueue(d->mArguments);
+    }
 }
 
 QAction * ElisaApplication::action(const QString& name)
@@ -341,6 +459,21 @@ AllArtistsProxyModel *ElisaApplication::allArtistsProxyModel() const
     return d->mAllArtistsProxyModel.get();
 }
 
+AllArtistsProxyModel *ElisaApplication::allGenresProxyModel() const
+{
+    return d->mAllGenresProxyModel.get();
+}
+
+AllArtistsProxyModel *ElisaApplication::allComposersProxyModel() const
+{
+    return d->mAllComposersProxyModel.get();
+}
+
+AllArtistsProxyModel *ElisaApplication::allLyricistsProxyModel() const
+{
+    return d->mAllLyricistsProxyModel.get();
+}
+
 AllTracksProxyModel *ElisaApplication::allTracksProxyModel() const
 {
     return d->mAllTracksProxyModel.get();
@@ -356,10 +489,34 @@ SingleAlbumProxyModel *ElisaApplication::singleAlbumProxyModel() const
     return d->mSingleAlbumProxyModel.get();
 }
 
+FileBrowserProxyModel *ElisaApplication::fileBrowserProxyModel() const
+{
+    return d->mFileBrowserProxyModel.get();
+}
+
 MediaPlayList *ElisaApplication::mediaPlayList() const
 {
     return d->mMediaPlayList.get();
 }
 
+AudioWrapper *ElisaApplication::audioPlayer() const
+{
+    return d->mAudioWrapper.get();
+}
+
+ManageAudioPlayer *ElisaApplication::audioControl() const
+{
+    return d->mAudioControl.get();
+}
+
+ManageMediaPlayerControl *ElisaApplication::playerControl() const
+{
+    return d->mPlayerControl.get();
+}
+
+ManageHeaderBar *ElisaApplication::manageHeaderBar() const
+{
+    return d->mManageHeaderBar.get();
+}
 
 #include "moc_elisaapplication.cpp"
