@@ -20,6 +20,8 @@
 #ifndef ELISAAPPLICATION_H
 #define ELISAAPPLICATION_H
 
+#include "elisaLib_export.h"
+
 #include "config-upnp-qt.h"
 
 #include <QObject>
@@ -35,10 +37,15 @@ class AllArtistsProxyModel;
 class AllTracksProxyModel;
 class SingleArtistProxyModel;
 class SingleAlbumProxyModel;
+class FileBrowserProxyModel;
 class MediaPlayList;
+class AudioWrapper;
+class ManageAudioPlayer;
+class ManageMediaPlayerControl;
+class ManageHeaderBar;
 class ElisaApplicationPrivate;
 
-class ElisaApplication : public QObject
+class ELISALIB_EXPORT ElisaApplication : public QObject
 {
 
     Q_OBJECT
@@ -64,6 +71,18 @@ class ElisaApplication : public QObject
                READ allTracksProxyModel
                NOTIFY allTracksProxyModelChanged)
 
+    Q_PROPERTY(AllArtistsProxyModel *allGenresProxyModel
+               READ allGenresProxyModel
+               NOTIFY allGenresProxyModelChanged)
+
+    Q_PROPERTY(AllArtistsProxyModel *allComposersProxyModel
+               READ allComposersProxyModel
+               NOTIFY allComposersProxyModelChanged)
+
+    Q_PROPERTY(AllArtistsProxyModel *allLyricistsProxyModel
+               READ allLyricistsProxyModel
+               NOTIFY allLyricistsProxyModelChanged)
+
     Q_PROPERTY(SingleArtistProxyModel *singleArtistProxyModel
                READ singleArtistProxyModel
                NOTIFY singleArtistProxyModelChanged)
@@ -72,10 +91,30 @@ class ElisaApplication : public QObject
                READ singleAlbumProxyModel
                NOTIFY singleAlbumProxyModelChanged)
 
+    Q_PROPERTY(FileBrowserProxyModel *fileBrowserProxyModel
+               READ fileBrowserProxyModel
+               NOTIFY fileBrowserProxyModelChanged)
+
     Q_PROPERTY(MediaPlayList *mediaPlayList
                READ mediaPlayList
                NOTIFY mediaPlayListChanged)
 
+    Q_PROPERTY(AudioWrapper *audioPlayer
+               READ audioPlayer
+               NOTIFY audioPlayerChanged)
+
+    Q_PROPERTY(ManageAudioPlayer *audioControl
+               READ audioControl
+               NOTIFY audioControlChanged)
+
+    Q_PROPERTY(ManageMediaPlayerControl *playerControl
+               READ playerControl
+               NOTIFY playerControlChanged)
+
+    Q_PROPERTY(ManageHeaderBar *manageHeaderBar
+               READ manageHeaderBar
+               NOTIFY manageHeaderBarChanged)
+
 public:
     explicit ElisaApplication(QObject *parent = nullptr);
 
@@ -93,14 +132,30 @@ public:
 
     AllArtistsProxyModel *allArtistsProxyModel() const;
 
+    AllArtistsProxyModel *allGenresProxyModel() const;
+
+    AllArtistsProxyModel *allComposersProxyModel() const;
+
+    AllArtistsProxyModel *allLyricistsProxyModel() const;
+
     AllTracksProxyModel *allTracksProxyModel() const;
 
     SingleArtistProxyModel *singleArtistProxyModel() const;
 
     SingleAlbumProxyModel *singleAlbumProxyModel() const;
 
+    FileBrowserProxyModel *fileBrowserProxyModel() const;
+
     MediaPlayList *mediaPlayList() const;
 
+    AudioWrapper *audioPlayer() const;
+
+    ManageAudioPlayer *audioControl() const;
+
+    ManageMediaPlayerControl *playerControl() const;
+
+    ManageHeaderBar *manageHeaderBar() const;
+
 Q_SIGNALS:
 
     void argumentsChanged();
@@ -111,14 +166,30 @@ Q_SIGNALS:
 
     void allArtistsProxyModelChanged();
 
+    void allGenresProxyModelChanged();
+
+    void allComposersProxyModelChanged();
+
+    void allLyricistsProxyModelChanged();
+
     void allTracksProxyModelChanged();
 
     void singleArtistProxyModelChanged();
 
     void singleAlbumProxyModelChanged();
 
+    void fileBrowserProxyModelChanged();
+
     void mediaPlayListChanged();
 
+    void audioPlayerChanged();
+
+    void audioControlChanged();
+
+    void playerControlChanged();
+
+    void manageHeaderBarChanged();
+
     void enqueue(const QStringList &files);
 
 public Q_SLOTS:
@@ -147,8 +218,14 @@ private Q_SLOTS:
 
     void goBack();
 
+    void find();
+
 private:
 
+    void initializeModels();
+
+    void initializePlayer();
+
     void setupActions(const QString &actionName);
 
     QStringList checkFileListAndMakeAbsolute(const QStringList &filesList, const QString &workingDirectory) const;
