@@ -68,6 +68,7 @@ MediaPlayer2Player::MediaPlayer2Player(MediaPlayList *playListControler, ManageA
             this, &MediaPlayer2Player::playerVolumeChanged);
 
     m_volume = m_audioPlayer->volume();
+    m_canPlay = m_manageMediaPlayerControl->playControlEnabled();
     signalPropertiesChange(QStringLiteral("Volume"), Volume());
 
     m_mediaPlayerPresent = 1;
@@ -132,7 +133,7 @@ bool MediaPlayer2Player::CanPause() const
 void MediaPlayer2Player::Pause()
 {
     if (m_playListControler) {
-        m_manageAudioPlayer->playerPause();
+        m_manageAudioPlayer->ensurePause();
     }
 }
 
@@ -148,6 +149,10 @@ void MediaPlayer2Player::PlayPause()
 void MediaPlayer2Player::Stop()
 {
     emit stop();
+
+    if (m_playListControler) {
+        m_manageAudioPlayer->stop();
+    }
 }
 
 bool MediaPlayer2Player::CanPlay() const
@@ -235,8 +240,8 @@ bool MediaPlayer2Player::CanControl() const
 void MediaPlayer2Player::Seek(qlonglong Offset)
 {
     if (mediaPlayerPresent()) {
-        int offset = (m_position + Offset) / 1000;
-        m_manageAudioPlayer->playerSeek(offset);
+        auto offset = (m_position + Offset) / 1000;
+        m_manageAudioPlayer->playerSeek(int(offset));
     }
 }
 
@@ -248,7 +253,7 @@ void MediaPlayer2Player::emitSeeked(int pos)
 void MediaPlayer2Player::SetPosition(const QDBusObjectPath &trackId, qlonglong pos)
 {
     if (trackId.path() == m_currentTrackId) {
-        m_manageAudioPlayer->playerSeek(pos / 1000);
+        m_manageAudioPlayer->playerSeek(int(pos / 1000));
     }
 }
 
